@@ -77,3 +77,7 @@ new_sparse_logical <- function(values, positions, length, default) {
 
   .Call(ffi_altrep_new_sparse_logical, x)
 }
+
+sparse_logical_materialize <- function(x) {
+  .Call(ffi_altrep_sparse_logical_materialize, x)
+}
