@@ -51,11 +51,15 @@ SEXP alrep_sparse_logical_Materialize(SEXP x) {
   return out;
 }
 
+SEXP ffi_altrep_sparse_logical_materialize(SEXP x) {
+  return alrep_sparse_logical_Materialize(x);
+}
+
 // -----------------------------------------------------------------------------
 // ALTVEC
 
 void* altrep_sparse_logical_Dataptr(SEXP x, Rboolean writeable) {
-  return SVCTRS_DATAPTR(alrep_sparse_logical_Materialize(x));
+  return DATAPTR_RW(alrep_sparse_logical_Materialize(x));
 }
 
 const void* altrep_sparse_logical_Dataptr_or_null(SEXP x) {
@@ -64,7 +68,7 @@ const void* altrep_sparse_logical_Dataptr_or_null(SEXP x) {
   if (out == R_NilValue) {
     return NULL;
   } else {
-    return SVCTRS_DATAPTR(out);
+    return DATAPTR_RW(out);
   }
 }
 
@@ -207,6 +211,12 @@ SEXP altrep_sparse_logical_Duplicate(SEXP x, Rboolean deep) {
 // ALTLOGICAL
 
 static int altrep_sparse_logical_Elt(SEXP x, R_xlen_t i) {
+  SEXP data2 = R_altrep_data2(x);
+
+  if (data2 != R_NilValue) {
+    return LOGICAL_ELT(data2, i);
+  }
+
   SEXP val = extract_val(x);
 
   SEXP pos = extract_pos(x);
